@@ -13,7 +13,10 @@ usmNoAuthProtocol = config.usmNoAuthProtocol
 
 # Privacy protocol
 usmDESPrivProtocol = config.usmDESPrivProtocol
+usm3DESEDEPrivProtocol = config.usm3DESEDEPrivProtocol
 usmAesCfb128Protocol = config.usmAesCfb128Protocol
+usmAesCfb192Protocol = config.usmAesCfb192Protocol
+usmAesCfb256Protocol = config.usmAesCfb256Protocol
 usmNoPrivProtocol = config.usmNoPrivProtocol
 
 nextID = nextid.Integer(0xffffffffL)
@@ -142,7 +145,7 @@ class AsynCommandGenerator:
     def cfgCmdGen(self, authData, transportTarget, tagList=''):
         if isinstance(authData, CommunityData):
             tagList = '%s %s' % (tagList, authData.securityName)
-        if self.__knownAuths.has_key(authData):
+        if authData in self.__knownAuths:
             paramsName = self.__knownAuths[authData]
         else:
             paramsName = 'p%s' % nextID()
@@ -176,7 +179,7 @@ class AsynCommandGenerator:
                 raise error.PySnmpError('Unsupported authentication object')
             self.__knownAuths[authData] = paramsName
 
-        if not self.__knownTransports.has_key(transportTarget.transportDomain):
+        if transportTarget.transportDomain not in self.__knownTransports:
             transport = transportTarget.openClientMode()
             config.addSocketTransport(
                 self.snmpEngine,
@@ -186,7 +189,7 @@ class AsynCommandGenerator:
             self.__knownTransports[transportTarget.transportDomain] = transport
 
         k = paramsName, transportTarget, tagList
-        if self.__knownTransportAddrs.has_key(k):
+        if k in self.__knownTransportAddrs:
             addrName = self.__knownTransportAddrs[k]
         else:
             addrName = 'a%s' % nextID()
@@ -237,26 +240,36 @@ class AsynCommandGenerator:
                 )
         self.__knownTransportAddrs.clear()
                 
+    def makeReadVarBinds(self, varNames):
+        varBinds = []
+        for varName in varNames:
+            if type(varName[0]) in (types.IntType, types.LongType):
+                name = varName
+            else:
+                name, oid = mibvar.mibNameToOid(
+                    self.mibViewController, varName
+                    )
+                name = name + oid
+            varBinds.append((name, self._null))
+        return varBinds
+
     # Async SNMP apps
-    
-    def asyncGetCmd(
+
+    def getCmd(
         self, authData, transportTarget, varNames, (cbFun, cbCtx)
         ):
         addrName, paramsName = self.cfgCmdGen(
             authData, transportTarget
             )
-        varBinds = []
-        for varName in varNames:
-            name, oid = mibvar.mibNameToOid(
-                self.mibViewController, varName
-                )
-            varBinds.append((name + oid, self._null))
+        varBinds = self.makeReadVarBinds(varNames)
         return cmdgen.GetCommandGenerator().sendReq(
             self.snmpEngine, addrName, varBinds, cbFun, cbCtx,
             authData.contextEngineId, authData.contextName
             )
-
-    def asyncSetCmd(
+    
+    asyncGetCmd = getCmd
+    
+    def setCmd(
         self, authData, transportTarget, varBinds, (cbFun, cbCtx)
         ):
         addrName, paramsName = self.cfgCmdGen(
@@ -284,45 +297,51 @@ class AsynCommandGenerator:
             self.snmpEngine, addrName, __varBinds, cbFun, cbCtx,
             authData.contextEngineId, authData.contextName
             )
-        
-    def asyncNextCmd(
+    
+    asyncSetCmd = setCmd
+    
+    def nextCmd(
         self, authData, transportTarget, varNames, (cbFun, cbCtx)
         ):
         addrName, paramsName = self.cfgCmdGen(
             authData, transportTarget
             )
-        varBinds = []
-        for varName in varNames:
-            name, oid = mibvar.mibNameToOid(
-                self.mibViewController, varName
-                )
-            varBinds.append((name + oid, self._null))
+        varBinds = self.makeReadVarBinds(varNames)
         return cmdgen.NextCommandGenerator().sendReq(
             self.snmpEngine, addrName, varBinds, cbFun, cbCtx,
             authData.contextEngineId, authData.contextName
             )
 
-    def asyncBulkCmd(
+    asyncNextCmd = nextCmd
+    
+    def bulkCmd(
         self, authData, transportTarget, nonRepeaters, maxRepetitions,
         varNames, (cbFun, cbCtx)
         ):
         addrName, paramsName = self.cfgCmdGen(
             authData, transportTarget
             )
-        varBinds = []
-        for varName in varNames:
-            name, oid = mibvar.mibNameToOid(
-                self.mibViewController, varName
-                )
-            varBinds.append((name + oid, self._null))
+        varBinds = self.makeReadVarBinds(varNames)
         return cmdgen.BulkCommandGenerator().sendReq(
             self.snmpEngine, addrName,
             nonRepeaters, maxRepetitions, varBinds, cbFun, cbCtx,
             authData.contextEngineId, authData.contextName
             )
 
-class CommandGenerator(AsynCommandGenerator):
+    asyncBulkCmd = bulkCmd
+
+class CommandGenerator:
     lexicographicMode = None
+    def __init__(self, snmpEngine=None, asynCmdGen=None):
+        if asynCmdGen is None:
+            self.__asynCmdGen = AsynCommandGenerator(snmpEngine)
+        else:
+            self.__asynCmdGen = asynCmdGen
+
+        # compatibility attributes
+        self.snmpEngine = self.__asynCmdGen.snmpEngine
+        self.mibViewController = self.__asynCmdGen.mibViewController
+        
     def getCmd(self, authData, transportTarget, *varNames):
         def __cbFun(
             sendRequestHandle, errorIndication, errorStatus, errorIndex,
@@ -334,10 +353,10 @@ class CommandGenerator(AsynCommandGenerator):
             appReturn['varBinds'] = varBinds
 
         appReturn = {}
-        self.asyncGetCmd(
+        self.__asynCmdGen.getCmd(
             authData, transportTarget, varNames, (__cbFun, appReturn)
             )
-        self.snmpEngine.transportDispatcher.runDispatcher()
+        self.__asynCmdGen.snmpEngine.transportDispatcher.runDispatcher()
         return (
             appReturn['errorIndication'],
             appReturn['errorStatus'],
@@ -356,10 +375,10 @@ class CommandGenerator(AsynCommandGenerator):
             appReturn['varBinds'] = varBinds
 
         appReturn = {}
-        self.asyncSetCmd(
+        self.__asynCmdGen.setCmd(
             authData, transportTarget, varBinds, (__cbFun, appReturn)
             )
-        self.snmpEngine.transportDispatcher.runDispatcher()
+        self.__asynCmdGen.snmpEngine.transportDispatcher.runDispatcher()
         return (
             appReturn['errorIndication'],
             appReturn['errorStatus'],
@@ -405,16 +424,21 @@ class CommandGenerator(AsynCommandGenerator):
                 varBindTotalTable.extend(varBindTable)
 
             return 1 # continue table retrieval
-        
-        varBindHead = map(lambda (x,y),self=self: univ.ObjectIdentifier(x+y), map(lambda x,self=self: mibvar.mibNameToOid(self.mibViewController, x), varNames))
+
+        varBindHead = []
+        for varName in varNames:
+            name, suffix = mibvar.mibNameToOid(
+                self.__asynCmdGen.mibViewController, varName
+                )
+            varBindHead.append(univ.ObjectIdentifier(name + suffix))
 
         appReturn = {}
-        self.asyncNextCmd(
+        self.__asynCmdGen.nextCmd(
             authData, transportTarget, varNames,
             (__cbFun, (self, varBindHead,[],appReturn))
             )
 
-        self.snmpEngine.transportDispatcher.runDispatcher()
+        self.__asynCmdGen.snmpEngine.transportDispatcher.runDispatcher()
 
         return (
             appReturn['errorIndication'],
@@ -463,17 +487,22 @@ class CommandGenerator(AsynCommandGenerator):
                     return
                 
             return 1 # continue table retrieval
-        
-        varBindHead = map(lambda (x,y),self=self: univ.ObjectIdentifier(x+y), map(lambda x,self=self: mibvar.mibNameToOid(self.mibViewController, x), varNames))
+
+        varBindHead = []
+        for varName in varNames:
+            name, suffix = mibvar.mibNameToOid(
+                self.__asynCmdGen.mibViewController, varName
+                )
+            varBindHead.append(univ.ObjectIdentifier(name + suffix))
 
         appReturn = {}
         
-        self.asyncBulkCmd(
+        self.__asynCmdGen.bulkCmd(
             authData, transportTarget, nonRepeaters, maxRepetitions,
             varNames, (__cbFun, (self, varBindHead, [], appReturn))
             )
 
-        self.snmpEngine.transportDispatcher.runDispatcher()
+        self.__asynCmdGen.snmpEngine.transportDispatcher.runDispatcher()
         
         return (
             appReturn['errorIndication'],
