@@ -30,7 +30,7 @@ class VarBindAPI:
     def setOIDVal(self, varBind, (oid, val)):
         varBind.setComponentByPosition(0, oid)
         if val is None: val = self._null
-        varBind.setComponentByPosition(1).getComponentByPosition(1).setComponentByType(val.getTagSet(), val, 1)
+        varBind.setComponentByPosition(1).getComponentByPosition(1).setComponentByType(val.getTagSet(), val, 1, verifyConstraints=False)
         return varBind
     
     def getOIDVal(self, varBind):
@@ -38,15 +38,21 @@ class VarBindAPI:
 
 apiVarBind = VarBindAPI()
 
-getNextRequestID = nextid.Integer(0xffff)
+getNextRequestID = nextid.Integer(0xffffff)
 
 class PDUAPI:
-    _null = univ.Null('')
-    
+    _null = Null('')
+    _errorStatus = _errorIndex = Integer(0)
     def setDefaults(self, pdu):
-        pdu.setComponentByPosition(0, getNextRequestID())
-        pdu.setComponentByPosition(1, 0)
-        pdu.setComponentByPosition(2, 0)
+        pdu.setComponentByPosition(
+            0, getNextRequestID(), verifyConstraints=False
+            )
+        pdu.setComponentByPosition(
+            1, self._errorStatus, verifyConstraints=False
+            )
+        pdu.setComponentByPosition(
+            2, self._errorIndex, verifyConstraints=False
+            )
         pdu.setComponentByPosition(3)
         
     def getRequestID(self, pdu): return pdu.getComponentByPosition(0)
@@ -73,12 +79,14 @@ class PDUAPI:
     
     def getVarBindList(self, pdu):
         return pdu.getComponentByPosition(3)
+
     def setVarBindList(self, pdu, varBindList):
         varBindList = pdu.setComponentByPosition(3, varBindList)
-
     def getVarBinds(self, pdu):
-        return map(lambda x: apiVarBind.getOIDVal(x),
-                   pdu.getComponentByPosition(3))
+        varBinds = []
+        for varBind in pdu.getComponentByPosition(3):
+            varBinds.append(apiVarBind.getOIDVal(varBind))
+        return varBinds
     def setVarBinds(self, pdu, varBinds):
         varBindList = pdu.setComponentByPosition(3).getComponentByPosition(3)
         varBindList.clear()
@@ -101,9 +109,10 @@ class PDUAPI:
 
     def getVarBindTable(self, reqPDU, rspPDU):
         if apiPDU.getErrorStatus(rspPDU) == 2:
-            return [
-                map(lambda (x,y),self=self: (x, self._null), apiPDU.getVarBinds(reqPDU))
-                ]
+            varBindRow = []
+            for varBind in apiPDU.getVarBinds(reqPDU):
+                varBindRow.append((varBind[0], self._null))
+            return [ varBindRow ]
         else:
             return [ apiPDU.getVarBinds(rspPDU) ]
 
@@ -115,12 +124,14 @@ class TrapPDUAPI:
         agentAddress = IpAddress(socket.gethostbyname(socket.gethostname()))
     except:
         agentAddress = IpAddress('0.0.0.0')
+    _entOid = ObjectIdentifier((1,3,6,1,4,1,20408))
+    _zeroInt = univ.Integer(0)
     def setDefaults(self, pdu):
-        pdu.setComponentByPosition(0, (1,3,6,1,4,1,20408))
-        pdu.setComponentByPosition(1).getComponentByPosition(1).setComponentByPosition(0, self.agentAddress)
-        pdu.setComponentByPosition(2, 0)
-        pdu.setComponentByPosition(3, 0)
-        pdu.setComponentByPosition(4, 0)
+        pdu.setComponentByPosition(0, self._entOid, verifyConstraints=False)
+        pdu.setComponentByPosition(1).getComponentByPosition(1).setComponentByPosition(0, self.agentAddress, verifyConstraints=False)
+        pdu.setComponentByPosition(2, self._zeroInt, verifyConstraints=False)
+        pdu.setComponentByPosition(3, self._zeroInt, verifyConstraints=False)
+        pdu.setComponentByPosition(4, self._zeroInt, verifyConstraints=False)
         pdu.setComponentByPosition(5)
 
     def getEnterprise(self, pdu): return pdu.getComponentByPosition(0)
@@ -146,8 +157,10 @@ class TrapPDUAPI:
         varBindList = pdu.setComponentByPosition(5, varBindList)
 
     def getVarBinds(self, pdu):
-        return map(lambda x: apiVarBind.getOIDVal(x),
-                   pdu.getComponentByPosition(5))
+        varBinds = []
+        for varBind in pdu.getComponentByPosition(5):
+            varBinds.append(apiVarBind.getOIDVal(varBind))
+        return varBinds
     def setVarBinds(self, pdu, varBinds):
         varBindList = pdu.setComponentByPosition(5).getComponentByPosition(5)
         varBindList.clear()
@@ -165,9 +178,11 @@ class TrapPDUAPI:
 apiTrapPDU = TrapPDUAPI()
 
 class MessageAPI:
+    _verInt = univ.Integer(0)
+    _commStr = univ.OctetString('public')
     def setDefaults(self, msg):
-        msg.setComponentByPosition(0, 0)
-        msg.setComponentByPosition(1, 'public')
+        msg.setComponentByPosition(0, self._verInt, verifyConstraints=False)
+        msg.setComponentByPosition(1, self._commStr, verifyConstraints=False)
         return msg
 
     def getVersion(self, msg): return msg.getComponentByPosition(0)
@@ -178,7 +193,7 @@ class MessageAPI:
         
     def getPDU(self, msg): return msg.getComponentByPosition(2).getComponent()
     def setPDU(self, msg, value):
-        msg.setComponentByPosition(2).getComponentByPosition(2).setComponentByType(value.getTagSet(), value, 1)
+        msg.setComponentByPosition(2).getComponentByPosition(2).setComponentByType(value.getTagSet(), value, 1, verifyConstraints=False)
 
     def getResponse(self, reqMsg):
         rspMsg = Message()
