@@ -10,7 +10,9 @@ class __AbstractMibSource:
         self.__magic = imp.get_magic()
         self.__sfx = {}
         for sfx, mode, typ in imp.get_suffixes():
-            self.__sfx[typ] = (sfx, len(sfx), mode)
+            if typ not in self.__sfx:
+                self.__sfx[typ] = []
+            self.__sfx[typ].append((sfx, len(sfx), mode))
         debug.logger & debug.flagBld and debug.logger('trying %s' % self)
 
     def __repr__(self):
@@ -22,9 +24,9 @@ class __AbstractMibSource:
             if f[:9] == '__init__.':
                 continue
             for typ in (imp.PY_SOURCE, imp.PY_COMPILED):
-                sfx, sfxLen, mode = self.__sfx[typ]
-                if f[-sfxLen:] == sfx:
-                    u[f[:-sfxLen]] = None
+                for sfx, sfxLen, mode in self.__sfx[typ]:
+                    if f[-sfxLen:] == sfx:
+                        u[f[:-sfxLen]] = None
         return tuple(u.keys())
 
     # MibSource API follows
@@ -35,38 +37,41 @@ class __AbstractMibSource:
     def init(self): return self._init()
     def listdir(self): return self._listdir()
     def read(self, f):
-        pycSfx, pycSfxLen, pycMode = self.__sfx[imp.PY_COMPILED]
-        p = os.path.join(self._srcName, f) + pycSfx
-        try:
-            pycData = self._getData(p, pycMode)
-        except IOError:
-            pycTime = -1
-        else:
-            if self.__magic == pycData[:4]:
-                pycData = pycData[4:]
-                pycTime = struct.unpack('<L', pycData[:4])[0]
-                pycData = pycData[4:]
-            else:
-                debug.logger & debug.flagBld and debug.logger(
-                    'bad magic in %s' % p
-                    )
+        for pycSfx, pycSfxLen, pycMode in self.__sfx[imp.PY_COMPILED]:
+            p = os.path.join(self._srcName, f) + pycSfx
+            try:
+                pycData = self._getData(p, pycMode)
+            except IOError:
                 pycTime = -1
+            else:
+                if self.__magic == pycData[:4]:
+                    pycData = pycData[4:]
+                    pycTime = struct.unpack('<L', pycData[:4])[0]
+                    pycData = pycData[4:]
+                    break
+                else:
+                    debug.logger & debug.flagBld and debug.logger(
+                        'bad magic in %s' % p
+                        )
+                    pycTime = -1
 
         debug.logger & debug.flagBld and debug.logger(
             'file %s mtime %d' % (p, pycTime)
             )
-        
-        pySfx, pySfxLen, pyMode = self.__sfx[imp.PY_SOURCE]
-        p = os.path.join(self._srcName, f) + pySfx
-        try:
-            pyTime = self._getTimestamp(p)
-        except (IOError, OSError):
-            pyTime = -1
+
+        for pySfx, pySfxLen, pyMode in self.__sfx[imp.PY_SOURCE]:
+            p = os.path.join(self._srcName, f) + pySfx
+            try:
+                pyTime = self._getTimestamp(p)
+            except (IOError, OSError):
+                pyTime = -1
+            else:
+                break
 
         debug.logger & debug.flagBld and debug.logger(
             'file %s mtime %d' % (p, pyTime)
             )
-        
+
         if pycTime != -1 and pycTime >= pyTime:
             return marshal.loads(pycData), pycSfx
         if pyTime != -1:
@@ -107,7 +112,7 @@ class ZipMibSource(__AbstractMibSource):
         return tuple(self._uniqNames(l))
 
     def _getTimestamp(self, p):
-        if self.__loader._files.has_key(p):
+        if p in self.__loader._files:
             return self._parseDosTime(
                 self.__loader._files[p][6],
                 self.__loader._files[p][5]
@@ -142,9 +147,9 @@ class MibBuilder:
             ):
             sources.append(ZipMibSource(m).init())
         # Compatibility variable
-        if os.environ.has_key('PYSNMP_MIB_DIR'):
+        if 'PYSNMP_MIB_DIR' in os.environ:
             os.environ['PYSNMP_MIB_DIRS'] = os.environ['PYSNMP_MIB_DIR']
-        if os.environ.has_key('PYSNMP_MIB_DIRS'):
+        if 'PYSNMP_MIB_DIRS' in os.environ:
             for m in string.split(os.environ['PYSNMP_MIB_DIRS'], ':'):
                 sources.append(DirMibSource(m).init())
         if self.defaultMiscMibs:
@@ -201,7 +206,7 @@ class MibBuilder:
 
                 modPath = mibSource.fullPath(modName, sfx)
                 
-                if self.__modPathsSeen.has_key(modPath):
+                if modPath in self.__modPathsSeen:
                     debug.logger & debug.flagBld and debug.logger('loadModules: seen %s' % modPath)
                     break
                 else:
@@ -225,7 +230,7 @@ class MibBuilder:
 
                 break
 
-            if not self.__modSeen.has_key(modName):
+            if modName not in self.__modSeen:
                 raise error.SmiError(
                     'MIB file \"%s\" not found in search path' % (modName and modName + ".py[co]")
                     )
@@ -236,7 +241,7 @@ class MibBuilder:
         if not modNames:
             modNames = self.mibSymbols.keys()
         for modName in modNames:
-            if not self.mibSymbols.has_key(modName):
+            if modName not in self.mibSymbols:
                 raise error.SmiError(
                     'No module %s at %s' % (modName, self)
                     )
@@ -255,13 +260,13 @@ class MibBuilder:
             )
         r = ()
         for symName in symNames:
-            if not self.mibSymbols.has_key(modName):
+            if modName not in self.mibSymbols:
                 self.loadModules(modName)
-            if not self.mibSymbols.has_key(modName):
+            if modName not in self.mibSymbols:
                 raise error.SmiError(
                     'No module %s loaded at %s' % (modName, self)
                     )
-            if not self.mibSymbols[modName].has_key(symName):
+            if symName not in self.mibSymbols[modName]:
                 raise error.SmiError(
                     'No symbol %s::%s at %s' % (modName, symName, self)
                     )
@@ -269,7 +274,7 @@ class MibBuilder:
         return r
 
     def exportSymbols(self, modName, *anonymousSyms, **namedSyms):
-        if not self.mibSymbols.has_key(modName):
+        if modName not in self.mibSymbols:
             self.mibSymbols[modName] = {}
         mibSymbols = self.mibSymbols[modName]
         
@@ -278,7 +283,7 @@ class MibBuilder:
             mibSymbols['__pysnmp_%ld' % self._autoName] = symObj
             self._autoName = self._autoName + 1
         for symName, symObj in namedSyms.items():
-            if mibSymbols.has_key(symName):
+            if symName in mibSymbols:
                 raise error.SmiError(
                     'Symbol %s already exported at %s' % (symName, modName)
                     )
@@ -295,7 +300,7 @@ class MibBuilder:
         self.lastBuildId = self.lastBuildId + 1
 
     def unexportSymbols(self, modName, *symNames):
-        if not self.mibSymbols.has_key(modName):
+        if modName not in self.mibSymbols:
             raise error.SmiError(
                 'No module %s at %s' % (modName, self)
                 )
@@ -303,7 +308,7 @@ class MibBuilder:
         if not symNames:
             symNames = mibSymbols.keys()
         for symName in symNames:
-            if not mibSymbols.has_key(symName):
+            if symName not in mibSymbols:
                 raise error.SmiError(
                     'No symbol %s::%s at %s' % (modName, symName, self)
                     )
